WidgetPositioningX extension

Extension methods for positioning widgets

on

Properties

positionedBottom Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the bottom of a Stack
no setter
positionedBottomLeft Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the bottom-left of a Stack
no setter
positionedBottomRight Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the bottom-right of a Stack
no setter
positionedCenter Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the center of a Stack
no setter
positionedLeft Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the left of a Stack
no setter
positionedRight Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the right of a Stack
no setter
positionedTop Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the top of a Stack
no setter
positionedTopLeft Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the top-left of a Stack
no setter
positionedTopRight Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget at the top-right of a Stack
no setter
safeArea Widget

Available on Widget, provided by the WidgetPositioningX extension

Wrap with SafeArea
no setter

Methods

positioned({double? left, double? top, double? right, double? bottom, double? width, double? height}) Widget

Available on Widget, provided by the WidgetPositioningX extension

Position the widget in a Stack