positionedBottom property
Widget
get
positionedBottom
Position the widget at the bottom of a Stack
Implementation
Widget get positionedBottom => Positioned(bottom: 0, left: 0, right: 0, child: this);
Position the widget at the bottom of a Stack
Widget get positionedBottom => Positioned(bottom: 0, left: 0, right: 0, child: this);