positionedCenter property
Widget
get
positionedCenter
Position the widget at the center of a Stack
Implementation
Widget get positionedCenter => Positioned.fill(child: center);
Position the widget at the center of a Stack
Widget get positionedCenter => Positioned.fill(child: center);