positionedLeft property
Widget
get
positionedLeft
Position the widget at the left of a Stack
Implementation
Widget get positionedLeft => Positioned(left: 0, top: 0, bottom: 0, child: this);
Position the widget at the left of a Stack
Widget get positionedLeft => Positioned(left: 0, top: 0, bottom: 0, child: this);