positionedRight property
Widget
get
positionedRight
Position the widget at the right of a Stack
Implementation
Widget get positionedRight => Positioned(right: 0, top: 0, bottom: 0, child: this);
Position the widget at the right of a Stack
Widget get positionedRight => Positioned(right: 0, top: 0, bottom: 0, child: this);