positionedTop property
Widget
get
positionedTop
Position the widget at the top of a Stack
Implementation
Widget get positionedTop => Positioned(top: 0, left: 0, right: 0, child: this);
Position the widget at the top of a Stack
Widget get positionedTop => Positioned(top: 0, left: 0, right: 0, child: this);