WidgetSizingX extension
Extension methods for sizing widgets
- on
Properties
- expand → Widget
-
Available on Widget, provided by the WidgetSizingX extension
Expand the widget to fill the available spaceno setter
Methods
-
aspectRatio(
double aspectRatio) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Set aspect ratio for the widget -
constrain(
{double? minWidth, double? maxWidth, double? minHeight, double? maxHeight}) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Constrain the widget with minimum and maximum sizes -
flexible(
[int flex = 1]) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Make the widget flexible with a flex factor -
height(
double height) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Set height for the widget -
size(
double width, double height) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Set both width and height for the widget -
square(
double size) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Set size as a square (same width and height) -
width(
double width) → Widget -
Available on Widget, provided by the WidgetSizingX extension
Set width for the widget