WidgetPositioningX extension
Extension methods for positioning widgets
- on
Properties
- positionedBottom → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the bottom of a Stackno setter - positionedBottomLeft → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the bottom-left of a Stackno setter - positionedBottomRight → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the bottom-right of a Stackno setter - positionedCenter → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the center of a Stackno setter - positionedLeft → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the left of a Stackno setter - positionedRight → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the right of a Stackno setter - positionedTop → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the top of a Stackno setter - positionedTopLeft → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the top-left of a Stackno setter - positionedTopRight → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Position the widget at the top-right of a Stackno setter - safeArea → Widget
-
Available on Widget, provided by the WidgetPositioningX extension
Wrap with SafeAreano setter
Methods
-
positioned(
{double? left, double? top, double? right, double? bottom, double? width, double? height}) → Widget -
Available on Widget, provided by the WidgetPositioningX extension
Position the widget in a Stack